@@ -7,6 +7,7 @@ Provides client-specific implementations and configuration
 from mcpm.clients.base import BaseClientManager
 from mcpm.clients.client_config import ClientConfigManager
 from mcpm.clients.client_registry import ClientRegistry
+from mcpm.clients.managers.claude_code import ClaudeCodeManager
 from mcpm.clients.managers.claude_desktop import ClaudeDesktopManager
 from mcpm.clients.managers.cursor import CursorManager
 from mcpm.clients.managers.trae import TraeManager
@@ -15,6 +16,7 @@ from mcpm.clients.managers.windsurf import WindsurfManager
 __all__ = [
     "BaseClientManager",
     "ClaudeDesktopManager",
+    "ClaudeCodeManager",
     "WindsurfManager",
     "CursorManager",
     "TraeManager",
