@@ -19,16 +19,16 @@ class CursorManager(JSONClientManager):
     display_name = "Cursor"
     download_url = "https://cursor.sh/download"
 
-    def __init__(self, config_path=None):
+    def __init__(self, config_path_override: str | None = None):
         """Initialize the Cursor client manager
 
         Args:
-            config_path: Optional path to the config file. If not provided, uses default path.
+            config_path_override: Optional path to override the default config file location
         """
-        super().__init__()
+        super().__init__(config_path_override=config_path_override)
 
-        if config_path:
-            self.config_path = config_path
+        if config_path_override:
+            self.config_path = config_path_override
         else:
             # Set config path based on detected platform
             if self._system == "Windows":
